@@ -242,7 +242,7 @@ void Workspace::setActiveWindow(Window *window)
 
         // activating a client can cause a non active fullscreen window to loose the ActiveLayer status on > 1 screens
         if (outputs().count() > 1) {
-            for (auto it = m_allClients.begin(); it != m_allClients.end(); ++it) {
+            for (auto it = m_windows.begin(); it != m_windows.end(); ++it) {
                 if (*it != m_activeWindow && (*it)->layer() == ActiveLayer && (*it)->output() == m_activeWindow->output()) {
                     (*it)->updateLayer();
                 }
@@ -289,6 +289,11 @@ void Workspace::activateWindow(Window *window, bool force)
     if (window->isDeleted()) {
         return;
     }
+    if (window->isHiddenByShowDesktop()) {
+        ++block_focus;
+        setShowingDesktop(false);
+        --block_focus;
+    }
     raiseWindow(window);
     if (!window->isOnCurrentDesktop()) {
         ++block_focus;
@@ -299,6 +304,8 @@ void Workspace::activateWindow(Window *window, bool force)
         case Options::ActivationDesktopPolicy::BringToCurrentDesktop:
             window->enterDesktop(VirtualDesktopManager::self()->currentDesktop());
             break;
+        case Options::ActivationDesktopPolicy::DoNothing:
+            break;
         }
         --block_focus;
     }
@@ -312,11 +319,11 @@ void Workspace::activateWindow(Window *window, bool force)
     }
 #endif
     if (window->isMinimized()) {
-        window->unminimize();
+        window->setMinimized(false);
     }
 
     // ensure the window is really visible - could eg. be a hidden utility window, see bug #348083
-    window->showClient();
+    window->setHidden(false);
 
     // TODO force should perhaps allow this only if the window already contains the mouse
     if (options->focusPolicyIsReasonable() || force) {
@@ -334,6 +341,8 @@ void Workspace::activateWindow(Window *window, bool force)
         // updateUserTime is X11 specific
         x11Window->updateUserTime();
     }
+
+    m_quickTileCombineTimer->stop();
 }
 
 /**
@@ -444,7 +453,7 @@ Window *Workspace::windowUnderMouse(Output *output) const
             continue;
         }
 
-        if (window->frameGeometry().contains(Cursors::self()->mouse()->pos())) {
+        if (exclusiveContains(window->frameGeometry(), Cursors::self()->mouse()->pos())) {
             return window;
         }
     }
@@ -542,7 +551,7 @@ void Workspace::switchToOutput(Output *output)
 
 void Workspace::gotFocusIn(const Window *window)
 {
-    if (should_get_focus.contains(const_cast<Window *>(window))) {
+    if (should_get_focus.contains(window)) {
         // remove also all sooner elements that should have got FocusIn,
         // but didn't for some reason (and also won't anymore, because they were sooner)
         while (should_get_focus.first() != window) {
@@ -622,7 +631,6 @@ void Workspace::windowAttentionChanged(Window *window, bool set)
     } else {
         attention_chain.removeAll(window);
     }
-    Q_EMIT windowDemandsAttentionChanged(window, set);
 }
 
 //********************************************
@@ -772,7 +780,13 @@ void X11Window::startupIdChanged()
     // launched). However don't affect the window's desktop if it's set to be on all desktops.
 
     if (asn_data.desktop() != 0 && !isOnAllDesktops()) {
-        workspace()->sendWindowToDesktop(this, asn_data.desktop(), true);
+        if (asn_data.desktop() == -1) {
+            workspace()->sendWindowToDesktops(this, {}, true);
+        } else {
+            if (VirtualDesktop *desktop = VirtualDesktopManager::self()->desktopForX11Id(asn_data.desktop())) {
+                workspace()->sendWindowToDesktops(this, {desktop}, true);
+            }
+        }
     }
 
     if (asn_data.xinerama() != -1) {
@@ -811,9 +825,7 @@ enum Level {
 }
 
 // focus_in -> the window got FocusIn event
-// ignore_desktop - call comes from _NET_ACTIVE_WINDOW message, don't refuse just because of window
-//     is on a different desktop
-bool X11Window::allowWindowActivation(xcb_timestamp_t time, bool focus_in, bool ignore_desktop)
+bool X11Window::allowWindowActivation(xcb_timestamp_t time, bool focus_in)
 {
     auto window = this;
     // options->focusStealingPreventionLevel :
@@ -857,11 +869,6 @@ bool X11Window::allowWindowActivation(xcb_timestamp_t time, bool focus_in, bool
         return false;
     }
 
-    // Desktop switching is only allowed in the "no protection" case
-    if (!ignore_desktop && !window->isOnCurrentDesktop()) {
-        return false; // allow only with level == 0
-    }
-
     // No active window, it's ok to pass focus
     // NOTICE that extreme protection needs to be handled before to allow protection on unmanged windows
     if (ac == nullptr || ac->isDesktop()) {
@@ -878,10 +885,6 @@ bool X11Window::allowWindowActivation(xcb_timestamp_t time, bool focus_in, bool
         return true;
     }
 
-    if (!window->isOnCurrentDesktop()) { // we allowed explicit self-activation across virtual desktops
-        return false; // inside a window or if no window was active, but not otherwise
-    }
-
     // High FPS, not intr-window change. Only allow if the active window has only minor interest
     if (level > FSP::Medium && protection > FSP::Low) {
         return false;
