@@ -37,6 +37,10 @@
 #include <xf86drm.h>
 #include <xf86drmMode.h>
 
+#ifndef DRM_CLIENT_CAP_CURSOR_PLANE_HOTSPOT
+#define DRM_CLIENT_CAP_CURSOR_PLANE_HOTSPOT 6
+#endif
+
 namespace KWin
 {
 
@@ -74,8 +78,8 @@ DrmGpu::DrmGpu(DrmBackend *backend, const QString &devNode, int fd, dev_t device
 
     // find out what driver this kms device is using
     DrmUniquePtr<drmVersion> version(drmGetVersion(fd));
-    m_isNVidia = strstr(version->name, "nvidia-drm");
     m_isI915 = strstr(version->name, "i915");
+    m_isNVidia = strstr(version->name, "nvidia-drm");
     m_isVirtualMachine = strstr(version->name, "virtio") || strstr(version->name, "qxl")
         || strstr(version->name, "vmwgfx") || strstr(version->name, "vboxvideo");
 
@@ -146,8 +150,9 @@ void DrmGpu::initDrmResources()
 {
     // try atomic mode setting
     bool isEnvVarSet = false;
-    bool noAMS = qEnvironmentVariableIntValue("KWIN_DRM_NO_AMS", &isEnvVarSet) != 0 && isEnvVarSet;
-    if (m_isVirtualMachine && !isEnvVarSet) {
+    const bool supportsVmCursorHotspot = drmSetClientCap(m_fd, DRM_CLIENT_CAP_CURSOR_PLANE_HOTSPOT, 1) == 0;
+    const bool noAMS = qEnvironmentVariableIntValue("KWIN_DRM_NO_AMS", &isEnvVarSet) != 0 && isEnvVarSet;
+    if (m_isVirtualMachine && !supportsVmCursorHotspot && !isEnvVarSet) {
         qCWarning(KWIN_DRM, "Atomic Mode Setting disabled on GPU %s because of cursor offset issues in virtual machines", qPrintable(m_devNode));
     } else if (noAMS) {
         qCWarning(KWIN_DRM) << "Atomic Mode Setting requested off via environment variable. Using legacy mode on GPU" << m_devNode;
@@ -356,8 +361,6 @@ bool DrmGpu::updateOutputs()
 
 void DrmGpu::removeOutputs()
 {
-    waitIdle();
-
     const auto outputs = m_drmOutputs;
     for (const auto &output : outputs) {
         removeOutput(output);
@@ -557,7 +560,6 @@ void DrmGpu::pageFlipHandler(int fd, unsigned int sequence, unsigned int sec, un
         timestamp = std::chrono::steady_clock::now().time_since_epoch();
     }
     commit->pageFlipped(timestamp);
-    delete commit;
 }
 
 void DrmGpu::dispatchEvents()
@@ -686,16 +688,16 @@ bool DrmGpu::asyncPageflipSupported() const
     return m_asyncPageflipSupported;
 }
 
-bool DrmGpu::isNVidia() const
-{
-    return m_isNVidia;
-}
-
 bool DrmGpu::isI915() const
 {
     return m_isI915;
 }
 
+bool DrmGpu::isNVidia() const
+{
+    return m_isNVidia;
+}
+
 bool DrmGpu::isRemoved() const
 {
     return m_isRemoved;
