@@ -270,31 +270,26 @@ void DrmOutput::updateDpmsMode(DpmsMode dpmsMode)
 bool DrmOutput::present(const std::shared_ptr<OutputFrame> &frame)
 {
     m_frame = frame;
-    auto type = m_pipeline->contentType();
-    if (frame->contentType()) {
-        type = DrmConnector::kwinToDrmContentType(*frame->contentType());
-    }
-    if (m_pipeline->presentationMode() != frame->presentationMode() || type != m_pipeline->contentType()) {
-        m_pipeline->setPresentationMode(frame->presentationMode());
-        m_pipeline->setContentType(type);
-        if (DrmPipeline::commitPipelines({m_pipeline}, DrmPipeline::CommitMode::Test) == DrmPipeline::Error::None) {
-            m_pipeline->applyPendingChanges();
-        } else {
-            m_pipeline->revertPendingChanges();
-        }
-        m_renderLoop->setPresentationMode(m_pipeline->presentationMode());
-    }
     const bool needsModeset = gpu()->needsModeset();
     bool success;
     if (needsModeset) {
+        m_pipeline->setPresentationMode(PresentationMode::VSync);
+        m_pipeline->setContentType(DrmConnector::DrmContentType::Graphics);
         success = m_pipeline->maybeModeset();
     } else {
+        m_pipeline->setPresentationMode(frame->presentationMode());
         DrmPipeline::Error err = m_pipeline->present();
+        if (err != DrmPipeline::Error::None && frame->presentationMode() != PresentationMode::VSync) {
+            // retry with a more basic presentation mode
+            m_pipeline->setPresentationMode(PresentationMode::VSync);
+            err = m_pipeline->present();
+        }
         success = err == DrmPipeline::Error::None;
         if (err == DrmPipeline::Error::InvalidArguments) {
             QTimer::singleShot(0, m_gpu->platform(), &DrmBackend::updateOutputs);
         }
     }
+    m_renderLoop->setPresentationMode(m_pipeline->presentationMode());
     if (success) {
         Q_EMIT outputChange(m_pipeline->primaryLayer()->currentDamage());
         return true;
@@ -437,11 +432,12 @@ bool DrmOutput::doSetChannelFactors(const QVector3D &rgb)
     if (!m_pipeline->activePending()) {
         return false;
     }
+    const auto inGamma22 = ColorDescription::nitsToEncoded(rgb, NamedTransferFunction::gamma22, 1);
     if (m_pipeline->hasCTM()) {
         QMatrix3x3 ctm;
-        ctm(0, 0) = rgb.x();
-        ctm(1, 1) = rgb.y();
-        ctm(2, 2) = rgb.z();
+        ctm(0, 0) = inGamma22.x();
+        ctm(1, 1) = inGamma22.y();
+        ctm(2, 2) = inGamma22.z();
         m_pipeline->setCTM(ctm);
         m_pipeline->setGammaRamp(nullptr);
         if (DrmPipeline::commitPipelines({m_pipeline}, DrmPipeline::CommitMode::Test) == DrmPipeline::Error::None) {
@@ -454,7 +450,7 @@ bool DrmOutput::doSetChannelFactors(const QVector3D &rgb)
         }
     }
     if (m_pipeline->hasGammaRamp()) {
-        auto lut = ColorTransformation::createScalingTransform(rgb);
+        auto lut = ColorTransformation::createScalingTransform(inGamma22);
         if (lut) {
             m_pipeline->setGammaRamp(std::move(lut));
             if (DrmPipeline::commitPipelines({m_pipeline}, DrmPipeline::CommitMode::Test) == DrmPipeline::Error::None) {
@@ -478,7 +474,8 @@ QVector3D DrmOutput::channelFactors() const
 
 bool DrmOutput::needsColormanagement() const
 {
-    return m_state.wideColorGamut || m_state.highDynamicRange || m_state.iccProfile || m_channelFactorsNeedShaderFallback;
+    static bool forceColorManagement = qEnvironmentVariableIntValue("KWIN_DRM_FORCE_COLOR_MANAGEMENT") != 0;
+    return forceColorManagement || m_state.wideColorGamut || m_state.highDynamicRange || m_state.iccProfile || m_channelFactorsNeedShaderFallback;
 }
 }
 
