@@ -80,11 +80,6 @@ bool WaylandQPainterPrimaryLayer::endFrame(const QRegion &renderedRegion, const
     return true;
 }
 
-quint32 WaylandQPainterPrimaryLayer::format() const
-{
-    return DRM_FORMAT_RGBA8888;
-}
-
 std::chrono::nanoseconds WaylandQPainterPrimaryLayer::queryRenderTime() const
 {
     return m_renderTime;
@@ -131,11 +126,6 @@ bool WaylandQPainterCursorLayer::endFrame(const QRegion &renderedRegion, const Q
     return true;
 }
 
-quint32 WaylandQPainterCursorLayer::format() const
-{
-    return DRM_FORMAT_RGBA8888;
-}
-
 std::chrono::nanoseconds WaylandQPainterCursorLayer::queryRenderTime() const
 {
     return m_renderTime;
