@@ -133,12 +133,6 @@ void Compositor::handleFrameRequested(RenderLoop *renderLoop)
     composite(renderLoop);
 }
 
-uint Compositor::outputFormat(Output *output)
-{
-    OutputLayer *primaryLayer = m_backend->primaryLayer(output);
-    return primaryLayer->format();
-}
-
 void Compositor::composite(RenderLoop *renderLoop)
 {
     if (m_backend->checkGraphicsReset()) {
@@ -160,7 +154,7 @@ void Compositor::composite(RenderLoop *renderLoop)
     renderLoop->prepareNewFrame();
     auto frame = std::make_shared<OutputFrame>(renderLoop);
 
-    if (superLayer->needsRepaint()) {
+    if (primaryLayer->needsRepaint() || superLayer->needsRepaint()) {
         renderLoop->beginPaint();
 
         QRegion surfaceDamage = primaryLayer->repaints();
