@@ -6,7 +6,7 @@
 #pragma once
 #include <optional>
 
-#include <QMatrix3x3>
+#include <QMatrix4x4>
 #include <QVector2D>
 
 #include "kwin_export.h"
@@ -39,9 +39,9 @@ public:
     /**
      * @returns a matrix adapting XYZ values from the source whitepoint to the destination whitepoint with the Bradford transform
      */
-    static QMatrix3x3 chromaticAdaptationMatrix(QVector2D sourceWhitepoint, QVector2D destinationWhitepoint);
+    static QMatrix4x4 chromaticAdaptationMatrix(QVector2D sourceWhitepoint, QVector2D destinationWhitepoint);
 
-    static QMatrix3x3 calculateToXYZMatrix(QVector3D red, QVector3D green, QVector3D blue, QVector3D white);
+    static QMatrix4x4 calculateToXYZMatrix(QVector3D red, QVector3D green, QVector3D blue, QVector3D white);
 
     explicit Colorimetry(QVector2D red, QVector2D green, QVector2D blue, QVector2D white);
     explicit Colorimetry(QVector3D red, QVector3D green, QVector3D blue, QVector3D white);
@@ -49,16 +49,16 @@ public:
     /**
      * @returns a matrix that transforms from the linear RGB representation of colors in this colorimetry to the XYZ representation
      */
-    const QMatrix3x3 &toXYZ() const;
+    const QMatrix4x4 &toXYZ() const;
     /**
      * @returns a matrix that transforms from the XYZ representation to the linear RGB representation of colors in this colorimetry
      */
-    const QMatrix3x3 &fromXYZ() const;
+    const QMatrix4x4 &fromXYZ() const;
     /**
      * @returns a matrix that transforms from linear RGB in this colorimetry to linear RGB in the other colorimetry
      * the rendering intent is relative colorimetric
      */
-    QMatrix3x3 toOther(const Colorimetry &colorimetry) const;
+    QMatrix4x4 toOther(const Colorimetry &colorimetry) const;
     bool operator==(const Colorimetry &other) const;
     bool operator==(NamedColorimetry name) const;
     /**
@@ -76,8 +76,8 @@ private:
     QVector2D m_green;
     QVector2D m_blue;
     QVector2D m_white;
-    QMatrix3x3 m_toXYZ;
-    QMatrix3x3 m_fromXYZ;
+    QMatrix4x4 m_toXYZ;
+    QMatrix4x4 m_fromXYZ;
 };
 
 /**
@@ -127,6 +127,8 @@ public:
      * This color description describes display-referred sRGB, with a gamma22 transfer function
      */
     static const ColorDescription sRGB;
+    static QVector3D encodedToNits(const QVector3D &nits, NamedTransferFunction tf, double sdrBrightness);
+    static QVector3D nitsToEncoded(const QVector3D &rgb, NamedTransferFunction tf, double sdrBrightness);
 
 private:
     Colorimetry m_colorimetry;
