@@ -26,8 +26,9 @@ RenderLoopPrivate *RenderLoopPrivate::get(RenderLoop *loop)
     return loop->d.get();
 }
 
-RenderLoopPrivate::RenderLoopPrivate(RenderLoop *q)
+RenderLoopPrivate::RenderLoopPrivate(RenderLoop *q, Output *output)
     : q(q)
+    , output(output)
 {
     compositeTimer.setSingleShot(true);
     QObject::connect(&compositeTimer, &QTimer::timeout, q, [this]() {
@@ -51,11 +52,8 @@ void RenderLoopPrivate::scheduleRepaint()
     }
 
     // Estimate when it's a good time to perform the next compositing cycle.
-    // this safety margin is required for
-    // - the buffer readiness deadline in the drm backend, which is 1.8ms before vblank
-    // - scheduling and timer inaccuracies (estimated to be up to 1.2ms here)
-    const std::chrono::nanoseconds safetyMargin = std::chrono::milliseconds(3);
-    std::chrono::nanoseconds nextRenderTimestamp = nextPresentationTimestamp - renderJournal.result() - safetyMargin;
+    // the 1ms on top of the safety margin is required for timer and scheduler inaccuracies
+    std::chrono::nanoseconds nextRenderTimestamp = nextPresentationTimestamp - renderJournal.result() - safetyMargin - std::chrono::milliseconds(1);
 
     // If we can't render the frame before the deadline, start compositing immediately.
     if (nextRenderTimestamp < currentTime) {
@@ -100,7 +98,7 @@ void RenderLoopPrivate::notifyFrameCompleted(std::chrono::nanoseconds timestamp,
 
     notifyVblank(timestamp);
 
-    renderJournal.add(renderTime);
+    renderJournal.add(renderTime, timestamp);
     if (!inhibitCount) {
         maybeScheduleRepaint();
     }
@@ -141,8 +139,8 @@ void RenderLoopPrivate::invalidate()
     compositeTimer.stop();
 }
 
-RenderLoop::RenderLoop()
-    : d(std::make_unique<RenderLoopPrivate>(this))
+RenderLoop::RenderLoop(Output *output)
+    : d(std::make_unique<RenderLoopPrivate>(this, output))
 {
 }
 
@@ -193,15 +191,20 @@ void RenderLoop::setRefreshRate(int refreshRate)
     Q_EMIT refreshRateChanged();
 }
 
+void RenderLoop::setPresentationSafetyMargin(std::chrono::nanoseconds safetyMargin)
+{
+    d->safetyMargin = safetyMargin;
+}
+
 void RenderLoop::scheduleRepaint(Item *item)
 {
     if (d->pendingRepaint) {
         return;
     }
     const bool vrr = d->presentationMode == PresentationMode::AdaptiveSync || d->presentationMode == PresentationMode::AdaptiveAsync;
-    if (vrr && workspace()->activeWindow()) {
+    if (vrr && workspace()->activeWindow() && d->output) {
         Window *const activeWindow = workspace()->activeWindow();
-        if (activeWindow->surfaceItem() && item != activeWindow->surfaceItem() && activeWindow->surfaceItem()->refreshRateEstimation() >= 30) {
+        if (activeWindow->isOnOutput(d->output) && activeWindow->surfaceItem() && item != activeWindow->surfaceItem() && activeWindow->surfaceItem()->refreshRateEstimation() >= 30) {
             return;
         }
     }
