@@ -16,7 +16,6 @@
 #include "compositor.h"
 #include "core/output.h"
 #include "core/renderbackend.h"
-#include "core/renderlayer.h"
 #include "core/rendertarget.h"
 #include "core/renderviewport.h"
 #include "decorations/decorationbridge.h"
@@ -27,7 +26,10 @@
 #include "input_event.h"
 #include "inputmethod.h"
 #include "inputpanelv1window.h"
-#include "opengl/glutils.h"
+#include "keyboard_input.h"
+#include "opengl/glshader.h"
+#include "opengl/glshadermanager.h"
+#include "opengl/gltexture.h"
 #include "osd.h"
 #include "pointer_input.h"
 #include "scene/itemrenderer.h"
@@ -64,8 +66,6 @@
 #include <QWindow>
 #include <QtMath>
 
-#include <optional>
-
 namespace KWin
 {
 
@@ -443,6 +443,7 @@ void EffectsHandler::ungrabKeyboard()
     Q_ASSERT(keyboard_grab_effect != nullptr);
     doUngrabKeyboard();
     keyboard_grab_effect = nullptr;
+    input()->keyboard()->update();
 }
 
 void EffectsHandler::doUngrabKeyboard()
