@@ -159,9 +159,8 @@ OffscreenQuickView::~OffscreenQuickView()
         d->m_glcontext->makeCurrent(d->m_offscreenSurface.get());
     }
 
-    // Always delete render control first.
-    d->m_renderControl.reset();
     d->m_view.reset();
+    d->m_renderControl.reset();
 }
 
 bool OffscreenQuickView::automaticRepaint() const
@@ -214,13 +213,13 @@ void OffscreenQuickView::update()
             return;
         }
 
-        const QSize nativeSize = d->m_view->size() * d->m_view->effectiveDevicePixelRatio();
+        const QSize nativeSize = d->m_view->size() * d->m_view->devicePixelRatio();
         if (!d->m_fbo || d->m_fbo->size() != nativeSize) {
             d->m_textureExport.reset(nullptr);
 
             QOpenGLFramebufferObjectFormat fboFormat;
             fboFormat.setAttachment(QOpenGLFramebufferObject::CombinedDepthStencil);
-            fboFormat.setInternalTextureFormat(d->m_hasAlphaChannel ? GL_RGBA8 : GL_RGB8);
+            fboFormat.setInternalTextureFormat(GL_RGBA8);
 
             d->m_fbo = std::make_unique<QOpenGLFramebufferObject>(nativeSize, fboFormat);
             if (!d->m_fbo->isValid()) {
@@ -448,6 +447,8 @@ void OffscreenQuickView::setGeometry(const QRect &rect)
 {
     const QRect oldGeometry = d->m_view->geometry();
     d->m_view->setGeometry(rect);
+    // QWindow::setGeometry() won't sync output if there's no platform window.
+    d->m_view->setScreen(QGuiApplication::screenAt(rect.center()));
     Q_EMIT geometryChanged(oldGeometry, rect);
 }
 
