@@ -154,11 +154,11 @@ OutputTransform toKWinTransform(int rotation)
     case None:
         return OutputTransform::Normal;
     case Left:
-        return OutputTransform::Rotated90;
+        return OutputTransform::Rotate90;
     case Inverted:
-        return OutputTransform::Rotated180;
+        return OutputTransform::Rotate180;
     case Right:
-        return OutputTransform::Rotated270;
+        return OutputTransform::Rotate270;
     default:
         Q_UNREACHABLE();
     }
@@ -229,7 +229,7 @@ std::optional<std::pair<OutputConfiguration, QList<Output *>>> readOutputConfig(
                 props->overscan = globalInfo["overscan"].toInt();
             }
             if (const QJsonValue vrrpolicy = globalInfo["vrrpolicy"]; !vrrpolicy.isUndefined()) {
-                props->vrrPolicy = static_cast<RenderLoop::VrrPolicy>(vrrpolicy.toInt());
+                props->vrrPolicy = static_cast<VrrPolicy>(vrrpolicy.toInt());
             }
             if (const QJsonValue rgbrange = globalInfo["rgbrange"]; !rgbrange.isUndefined()) {
                 props->rgbRange = static_cast<Output::RgbRange>(rgbrange.toInt());
