@@ -8,15 +8,13 @@
 #include "core/output.h"
 #include "layershellv1window.h"
 #include "wayland/display.h"
-#include "wayland/layershell_v1_interface.h"
-#include "wayland/output_interface.h"
+#include "wayland/layershell_v1.h"
+#include "wayland/output.h"
 #include "wayland_server.h"
 #include "workspace.h"
 
 #include <QTimer>
 
-using namespace KWaylandServer;
-
 namespace KWin
 {
 
@@ -27,7 +25,7 @@ LayerShellV1Integration::LayerShellV1Integration(QObject *parent)
     : WaylandShellIntegration(parent)
 {
     LayerShellV1Interface *shell = new LayerShellV1Interface(waylandServer()->display(), this);
-    connect(shell, &KWaylandServer::LayerShellV1Interface::surfaceCreated,
+    connect(shell, &LayerShellV1Interface::surfaceCreated,
             this, &LayerShellV1Integration::createWindow);
 
     m_rearrangeTimer = new QTimer(this);
@@ -148,6 +146,8 @@ static void rearrangeLayer(const QList<LayerShellV1Window *> &windows, QRect *wo
             geometry.setBottom(window->virtualKeyboardGeometry().top());
         }
 
+        window->updateLayer();
+
         if (geometry.isValid()) {
             window->moveResize(geometry);
         } else {
@@ -216,3 +216,5 @@ void LayerShellV1Integration::scheduleRearrange()
 }
 
 } // namespace KWin
+
+#include "moc_layershellv1integration.cpp"
