@@ -17,6 +17,7 @@
 #include "core/outputbackend.h"
 #include "core/session.h"
 #include "cursor.h"
+#include "effect/effecthandler.h"
 #include "outline.h"
 #include "screenedge.h"
 #include "sm.h"
@@ -138,7 +139,7 @@ private:
     {
         KSelectionOwner::getAtoms();
         if (xa_version == XCB_ATOM_NONE) {
-            const QByteArray name(QByteArrayLiteral("VERSION"));
+            constexpr QByteArrayView name{"VERSION"};
             UniqueCPtr<xcb_intern_atom_reply_t> atom(xcb_intern_atom_reply(
                 kwinApp()->x11Connection(),
                 xcb_intern_atom_unchecked(kwinApp()->x11Connection(), false, name.length(), name.constData()),
@@ -151,7 +152,7 @@ private:
 
     xcb_atom_t make_selection_atom()
     {
-        QByteArray screen(QByteArrayLiteral("WM_S0"));
+        constexpr QByteArrayView screen{"WM_S0"};
         UniqueCPtr<xcb_intern_atom_reply_t> atom(xcb_intern_atom_reply(
             kwinApp()->x11Connection(),
             xcb_intern_atom_unchecked(kwinApp()->x11Connection(), false, screen.length(), screen.constData()),
@@ -181,6 +182,10 @@ ApplicationX11::ApplicationX11(int &argc, char **argv)
 ApplicationX11::~ApplicationX11()
 {
     setTerminating();
+    // need to unload all effects before destroying Workspace, as effects might call into Workspace
+    if (effects) {
+        effects->unloadAllEffects();
+    }
     destroyPlugins();
     destroyColorManager();
     destroyWorkspace();
@@ -238,6 +243,10 @@ PlatformCursorImage ApplicationX11::cursorImage() const
 void ApplicationX11::lostSelection()
 {
     sendPostedEvents();
+    // need to unload all effects before destroying Workspace, as effects might call into Workspace
+    if (effects) {
+        effects->unloadAllEffects();
+    }
     destroyPlugins();
     destroyColorManager();
     destroyWorkspace();
@@ -381,7 +390,6 @@ int main(int argc, char *argv[])
     // disable highdpi scaling
     setenv("QT_ENABLE_HIGHDPI_SCALING", "0", true);
 
-    qunsetenv("QT_DEVICE_PIXEL_RATIO");
     qunsetenv("QT_SCALE_FACTOR");
     qunsetenv("QT_SCREEN_SCALE_FACTORS");
 
