@@ -133,6 +133,11 @@ bool GLShader::compile(GLuint program, GLenum shaderType, const QByteArray &sour
         qCCritical(KWIN_OPENGL) << "Failed to compile" << typeName << "shader:"
                                 << "\n"
                                 << log;
+        size_t line = 0;
+        const auto split = source.split('\n');
+        for (const auto &l : split) {
+            qCCritical(KWIN_OPENGL).nospace() << "line " << line++ << ":" << l;
+        }
     } else if (length > 0) {
         qCDebug(KWIN_OPENGL) << "Shader compile log:" << log;
     }
@@ -458,7 +463,7 @@ bool GLShader::setColorspaceUniformsToSRGB(const ColorDescription &src)
 {
     return setUniform(GLShader::MatrixUniform::ColorimetryTransformation, src.colorimetry().toOther(src.sdrColorimetry()))
         && setUniform(GLShader::IntUniform::SourceNamedTransferFunction, int(src.transferFunction()))
-        && setUniform(GLShader::IntUniform::DestinationNamedTransferFunction, int(NamedTransferFunction::sRGB))
+        && setUniform(GLShader::IntUniform::DestinationNamedTransferFunction, int(NamedTransferFunction::gamma22))
         && setUniform(FloatUniform::SdrBrightness, src.sdrBrightness())
         && setUniform(FloatUniform::MaxHdrBrightness, src.sdrBrightness());
 }
