@@ -10,6 +10,7 @@
 */
 
 #include "gltexture_p.h"
+#include "opengl/glframebuffer.h"
 #include "opengl/glplatform.h"
 #include "opengl/glutils.h"
 #include "opengl/glutils_funcs.h"
@@ -359,9 +360,9 @@ void GLTexture::render(const QRectF &source, const QRegion &region, const QSizeF
 
         QMatrix4x4 textureMat;
         textureMat.translate(texWidth / 2, texHeight / 2);
-        textureMat *= d->m_textureToBufferTransform.toMatrix();
         // our Y axis is flipped vs OpenGL
         textureMat.scale(1, -1);
+        textureMat *= d->m_textureToBufferTransform.toMatrix();
         textureMat.translate(-texWidth / 2, -texHeight / 2);
         textureMat.scale(texWidth / rotatedSize.width(), texHeight / rotatedSize.height());
 
@@ -499,14 +500,14 @@ void GLTexturePrivate::updateMatrix()
     }
 
     m_matrix[NormalizedCoordinates].translate(0.5, 0.5);
-    m_matrix[NormalizedCoordinates] *= textureToBufferMatrix;
     // our Y axis is flipped vs OpenGL
     m_matrix[NormalizedCoordinates].scale(1, -1);
+    m_matrix[NormalizedCoordinates] *= textureToBufferMatrix;
     m_matrix[NormalizedCoordinates].translate(-0.5, -0.5);
 
     m_matrix[UnnormalizedCoordinates].translate(m_size.width() / 2, m_size.height() / 2);
-    m_matrix[UnnormalizedCoordinates] *= textureToBufferMatrix;
     m_matrix[UnnormalizedCoordinates].scale(1, -1);
+    m_matrix[UnnormalizedCoordinates] *= textureToBufferMatrix;
     m_matrix[UnnormalizedCoordinates].translate(-m_size.width() / 2, -m_size.height() / 2);
 }
 
@@ -566,22 +567,28 @@ bool GLTexture::supportsFormatRG()
     return GLTexturePrivate::s_supportsTextureFormatRG;
 }
 
-QImage GLTexture::toImage() const
+QImage GLTexture::toImage()
 {
     if (target() != GL_TEXTURE_2D) {
         return QImage();
     }
     QImage ret(size(), QImage::Format_RGBA8888_Premultiplied);
 
-    GLint currentTextureBinding;
-    glGetIntegerv(GL_TEXTURE_BINDING_2D, &currentTextureBinding);
-
-    if (GLuint(currentTextureBinding) != texture()) {
-        glBindTexture(GL_TEXTURE_2D, texture());
-    }
-    glGetTexImage(GL_TEXTURE_2D, 0, GL_RGBA, GL_UNSIGNED_INT_8_8_8_8_REV, ret.bits());
-    if (GLuint(currentTextureBinding) != texture()) {
-        glBindTexture(GL_TEXTURE_2D, currentTextureBinding);
+    if (GLPlatform::instance()->isGLES()) {
+        GLFramebuffer fbo(this);
+        GLFramebuffer::pushFramebuffer(&fbo);
+        glReadPixels(0, 0, width(), height(), GL_RGBA, GL_UNSIGNED_INT_8_8_8_8_REV, ret.bits());
+        GLFramebuffer::popFramebuffer();
+    } else {
+        GLint currentTextureBinding;
+        glGetIntegerv(GL_TEXTURE_BINDING_2D, &currentTextureBinding);
+        if (GLuint(currentTextureBinding) != texture()) {
+            glBindTexture(GL_TEXTURE_2D, texture());
+        }
+        glGetTexImage(GL_TEXTURE_2D, 0, GL_RGBA, GL_UNSIGNED_INT_8_8_8_8_REV, ret.bits());
+        if (GLuint(currentTextureBinding) != texture()) {
+            glBindTexture(GL_TEXTURE_2D, currentTextureBinding);
+        }
     }
     return ret;
 }
