@@ -8,7 +8,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "platformsupport/scenes/opengl/openglbackend.h"
-#include "libkwineffects/glutils_funcs.h"
+#include "opengl/glutils_funcs.h"
 
 #include "utils/common.h"
 
@@ -83,10 +83,10 @@ bool OpenGLBackend::checkGraphicsReset()
     timer.start();
 
     // Wait until the reset is completed or max one second
-    while (timer.elapsed() < 1000 && KWin::glGetGraphicsResetStatus() != GL_NO_ERROR) {
+    while (timer.elapsed() < 10000 && KWin::glGetGraphicsResetStatus() != GL_NO_ERROR) {
         usleep(50);
     }
-    if (timer.elapsed() >= 1000) {
+    if (timer.elapsed() >= 10000) {
         qCWarning(KWIN_OPENGL) << "Waiting for glGetGraphicsResetStatus to return GL_NO_ERROR timed out!";
     }
 
