@@ -201,10 +201,9 @@ void MouseClickEffect::repaint()
         QRegion dirtyRegion;
         const int radius = m_ringMaxSize + m_lineWidth;
         for (auto &click : m_clicks) {
-            dirtyRegion |= QRect(click->m_pos.x() - radius, click->m_pos.y() - radius, 2 * radius, 2 * radius);
+            dirtyRegion += QRect(click->m_pos.x() - radius, click->m_pos.y() - radius, 2 * radius, 2 * radius);
             if (click->m_frame) {
-                // we grant the plasma style 32px padding for stuff like shadows...
-                dirtyRegion |= click->m_frame->geometry().adjusted(-32, -32, 32, 32);
+                dirtyRegion += click->m_frame->geometry();
             }
         }
         effects->addRepaint(dirtyRegion);
@@ -213,7 +212,7 @@ void MouseClickEffect::repaint()
         QRegion dirtyRegion;
         const int radius = m_ringMaxSize + m_lineWidth;
         for (const auto &event : std::as_const(m_tabletTools)) {
-            dirtyRegion |= QRect(event.m_globalPosition.x() - radius, event.m_globalPosition.y() - radius, 2 * radius, 2 * radius);
+            dirtyRegion += QRect(event.m_globalPosition.x() - radius, event.m_globalPosition.y() - radius, 2 * radius, 2 * radius);
         }
         effects->addRepaint(dirtyRegion);
     }
