@@ -94,18 +94,6 @@ bool PipeWireCore::init()
     return true;
 }
 
-std::shared_ptr<PipeWireCore> PipeWireCore::self()
-{
-    static std::weak_ptr<PipeWireCore> global;
-    auto ret = global.lock();
-    if (!ret) {
-        ret = std::make_shared<PipeWireCore>();
-        ret->init();
-        global = ret;
-    }
-    return ret;
-}
-
 } // namespace KWin
 
 #include "moc_pipewirecore.cpp"
