@@ -14,6 +14,7 @@ namespace KWin
 {
 
 class GLFramebuffer;
+class GLTexture;
 
 class ScreenCastSource : public QObject
 {
@@ -24,6 +25,7 @@ public:
 
     virtual uint refreshRate() const = 0;
     virtual bool hasAlphaChannel() const = 0;
+    virtual quint32 drmFormat() const = 0;
     virtual QSize textureSize() const = 0;
 
     virtual void render(GLFramebuffer *target) = 0;
