@@ -207,6 +207,7 @@ void ScreenCastStream::onStreamParamChanged(uint32_t id, const struct spa_pod *f
 
     qCDebug(KWIN_SCREENCAST) << "Stream format found, defining buffers";
     newStreamParams();
+    m_streaming = true;
 }
 
 void ScreenCastStream::onStreamAddBuffer(pw_buffer *buffer)
@@ -303,8 +304,9 @@ void ScreenCastStream::onStreamRenegotiateFormat(uint64_t)
     pw_stream_update_params(m_pwStream, params.data(), params.count());
 }
 
-ScreenCastStream::ScreenCastStream(ScreenCastSource *source, QObject *parent)
+ScreenCastStream::ScreenCastStream(ScreenCastSource *source, std::shared_ptr<PipeWireCore> pwCore, QObject *parent)
     : QObject(parent)
+    , m_pwCore(pwCore)
     , m_source(source)
     , m_resolution(source->textureSize())
 {
@@ -346,7 +348,6 @@ ScreenCastStream::~ScreenCastStream()
 
 bool ScreenCastStream::init()
 {
-    m_pwCore = PipeWireCore::self();
     if (!m_pwCore->m_error.isEmpty()) {
         m_error = m_pwCore->m_error;
         return false;
@@ -454,7 +455,7 @@ void ScreenCastStream::recordFrame(const QRegion &_damagedRegion)
     Q_ASSERT(!m_stopped);
 
     if (!m_streaming) {
-        m_pendingDamages |= damagedRegion;
+        m_pendingDamages += damagedRegion;
         return;
     }
 
@@ -462,7 +463,7 @@ void ScreenCastStream::recordFrame(const QRegion &_damagedRegion)
         auto frameInterval = (1000. * m_videoFormat.max_framerate.denom / m_videoFormat.max_framerate.num);
         auto lastSentAgo = m_lastSent.msecsTo(QDateTime::currentDateTimeUtc());
         if (lastSentAgo < frameInterval) {
-            m_pendingDamages |= damagedRegion;
+            m_pendingDamages += damagedRegion;
             if (!m_pendingFrame.isActive()) {
                 m_pendingFrame.start(frameInterval - lastSentAgo);
             }
@@ -534,7 +535,7 @@ void ScreenCastStream::recordFrame(const QRegion &_damagedRegion)
         m_source->render(spa_data, m_videoFormat.format);
 
         auto cursor = Cursors::self()->currentCursor();
-        if (m_cursor.mode == ScreencastV1Interface::Embedded && exclusiveContains(m_cursor.viewport, cursor->pos())) {
+        if (m_cursor.mode == ScreencastV1Interface::Embedded && includesCursor(cursor)) {
             QImage dest(data, size.width(), size.height(), stride, hasAlpha ? QImage::Format_RGBA8888_Premultiplied : QImage::Format_RGB888);
             QPainter painter(&dest);
             const auto position = (cursor->pos() - m_cursor.viewport.topLeft() - cursor->hotspot()) * m_cursor.scale;
@@ -556,7 +557,7 @@ void ScreenCastStream::recordFrame(const QRegion &_damagedRegion)
         m_source->render(buf->framebuffer());
 
         auto cursor = Cursors::self()->currentCursor();
-        if (m_cursor.mode == ScreencastV1Interface::Embedded && exclusiveContains(m_cursor.viewport, cursor->pos())) {
+        if (m_cursor.mode == ScreencastV1Interface::Embedded && includesCursor(cursor)) {
             if (m_cursor.invalid) {
                 m_cursor.invalid = false;
                 const PlatformCursorImage cursorImage = kwinApp()->cursorImage();
@@ -589,7 +590,7 @@ void ScreenCastStream::recordFrame(const QRegion &_damagedRegion)
                 damagedRegion += QRegion{m_cursor.lastRect.toAlignedRect()} | cursorRect.toAlignedRect();
                 m_cursor.lastRect = cursorRect;
             } else {
-                damagedRegion |= m_cursor.lastRect.toAlignedRect();
+                damagedRegion += m_cursor.lastRect.toAlignedRect();
                 m_cursor.lastRect = {};
             }
         }
@@ -668,7 +669,7 @@ void ScreenCastStream::recordCursor()
         return;
     }
 
-    if (!exclusiveContains(m_cursor.viewport, Cursors::self()->currentCursor()->pos()) && !m_cursor.visible) {
+    if (!includesCursor(Cursors::self()->currentCursor()) && !m_cursor.visible) {
         return;
     }
 
@@ -801,13 +802,21 @@ spa_pod *ScreenCastStream::buildFormat(struct spa_pod_builder *b, enum spa_video
     return (spa_pod *)spa_pod_builder_pop(b, &f[0]);
 }
 
+bool ScreenCastStream::includesCursor(Cursor *cursor) const
+{
+    if (Cursors::self()->isCursorHidden()) {
+        return false;
+    }
+    return m_cursor.viewport.intersects(cursor->geometry());
+}
+
 void ScreenCastStream::sendCursorData(Cursor *cursor, spa_meta_cursor *spa_meta_cursor)
 {
     if (!cursor || !spa_meta_cursor) {
         return;
     }
 
-    if (!exclusiveContains(m_cursor.viewport, cursor->pos())) {
+    if (!includesCursor(cursor)) {
         spa_meta_cursor->id = 0;
         spa_meta_cursor->position.x = -1;
         spa_meta_cursor->position.y = -1;
