@@ -50,7 +50,7 @@ class KWIN_EXPORT ScreenCastStream : public QObject
 {
     Q_OBJECT
 public:
-    explicit ScreenCastStream(ScreenCastSource *source, QObject *parent);
+    explicit ScreenCastStream(ScreenCastSource *source, std::shared_ptr<PipeWireCore> pwCore, QObject *parent);
     ~ScreenCastStream();
 
     bool init();
@@ -74,6 +74,7 @@ public:
 public Q_SLOTS:
     void invalidateCursor();
     void recordCursor();
+    bool includesCursor(Cursor *cursor) const;
 
 Q_SIGNALS:
     void streamReady(quint32 nodeId);
