@@ -13,6 +13,7 @@
 #include "opengl/gltexture.h"
 #include "opengl/glutils.h"
 #include "plugins/shakecursor/shakecursorconfig.h"
+#include "pointer_input.h"
 
 namespace KWin
 {
@@ -72,7 +73,11 @@ bool ShakeCursorEffect::isActive() const
 
 void ShakeCursorEffect::pointerEvent(MouseEvent *event)
 {
-    if (event->type() != QEvent::MouseMove) {
+    if (event->type() != QEvent::MouseMove || event->buttons() != Qt::NoButton) {
+        return;
+    }
+
+    if (input()->pointer()->isConstrained()) {
         return;
     }
 
@@ -83,12 +88,9 @@ void ShakeCursorEffect::pointerEvent(MouseEvent *event)
             .size = m_cursor->geometry().size(),
             .magnification = std::max(m_cursorMagnification, 1.0 + ShakeCursorConfig::magnification() * shakeFactor.value()),
         });
-        m_resetCursorScaleTimer.start(1000);
+        m_resetCursorScaleTimer.start(animationTime(2000));
         m_resetCursorScaleAnimation.stop();
     } else if (m_cursorMagnification != 1.0) {
-        if (m_resetCursorScaleAnimation.state() != QVariantAnimation::Running) {
-            m_resetCursorScaleTimer.start(0);
-        }
         update(Transaction{
             .position = m_cursor->pos(),
             .hotspot = m_cursor->hotspot(),
