@@ -7,13 +7,16 @@
 #pragma once
 
 #include "core/output.h"
+#include "effect/globals.h"
 #include "scene/item.h"
 
 namespace KWin
 {
 
 class DragAndDropIcon;
+class SurfaceInterface;
 class SurfaceItemWayland;
+class PresentationFeedback;
 
 class DragAndDropIconItem : public Item
 {
@@ -23,12 +26,13 @@ public:
     explicit DragAndDropIconItem(DragAndDropIcon *icon, Scene *scene, Item *parent = nullptr);
     ~DragAndDropIconItem() override;
 
-    void frameRendered(quint32 timestamp);
+    SurfaceInterface *surface() const;
 
     void setOutput(Output *output);
 
 private:
     std::unique_ptr<SurfaceItemWayland> m_surfaceItem;
+    Output *m_output = nullptr;
 };
 
 } // namespace KWin
