@@ -6,7 +6,7 @@
 
 #include "scene/imageitem.h"
 
-#include "libkwineffects/gltexture.h"
+#include "opengl/gltexture.h"
 
 namespace KWin
 {
