@@ -227,6 +227,20 @@ QList<QRectF> SurfaceItemXwayland::shape() const
     return shape;
 }
 
+QRegion SurfaceItemXwayland::opaque() const
+{
+    QRegion shapeRegion;
+    for (const QRectF &shapePart : shape()) {
+        shapeRegion += shapePart.toRect();
+    }
+    if (!m_window->hasAlpha()) {
+        return shapeRegion;
+    } else {
+        return m_window->opaqueRegion() & shapeRegion;
+    }
+    return QRegion();
+}
+
 } // namespace KWin
 
 #include "moc_surfaceitem_wayland.cpp"
