@@ -831,7 +831,7 @@ void ScreenEdges::reconfigure()
 
     // TODO: migrate settings to a group ScreenEdges
     KConfigGroup windowsConfig = m_config->group(QStringLiteral("Windows"));
-    setTimeThreshold(windowsConfig.readEntry("ElectricBorderDelay", 150));
+    setTimeThreshold(windowsConfig.readEntry("ElectricBorderDelay", 75));
     setReActivationThreshold(std::max(timeThreshold() + 50, windowsConfig.readEntry("ElectricBorderCooldown", 350)));
     int desktopSwitching = windowsConfig.readEntry("ElectricBorders", static_cast<int>(ElectricDisabled));
     if (desktopSwitching == ElectricDisabled) {
@@ -1105,14 +1105,12 @@ void ScreenEdges::recreateEdges()
             }
         }
     }
+    auto split = std::partition(oldEdges.begin(), oldEdges.end(), [](const auto &edge) {
+        return !edge->client();
+    });
     // copy over the effect/script reservations from the old edges
     for (const auto &edge : m_edges) {
-        for (const auto &oldEdge : oldEdges) {
-            if (oldEdge->client()) {
-                // show the client again and don't recreate the edge
-                oldEdge->client()->showOnScreenEdge();
-                continue;
-            }
+        for (const auto &oldEdge : std::span(oldEdges.begin(), split)) {
             if (oldEdge->border() != edge->border()) {
                 continue;
             }
@@ -1126,6 +1124,12 @@ void ScreenEdges::recreateEdges()
             }
         }
     }
+    // copy over the window reservations from the old edges
+    for (const auto &oldEdge : std::span(split, oldEdges.end())) {
+        if (!reserve(oldEdge->client(), oldEdge->border())) {
+            oldEdge->client()->showOnScreenEdge();
+        }
+    }
 }
 
 void ScreenEdges::createVerticalEdge(ElectricBorder border, const QRect &screen, const QRect &fullArea, Output *output)
@@ -1337,75 +1341,58 @@ bool ScreenEdges::createEdgeForClient(Window *client, ElectricBorder border)
     int x = 0;
     int width = 0;
     int height = 0;
+
+    Output *output = client->output();
     const QRect geo = client->frameGeometry().toRect();
     const QRect fullArea = workspace()->geometry();
 
-    const auto outputs = workspace()->outputs();
-    Output *foundOutput = nullptr;
-    for (Output *output : outputs) {
-        foundOutput = output;
-        const QRect screen = output->geometry();
-        if (!screen.contains(geo)) {
-            // ignoring Clients having a geometry overlapping with multiple screens
-            // this would make the code more complex. If it's needed in future it can be added
-            continue;
+    const QRect screen = output->geometry();
+    switch (border) {
+    case ElectricTop:
+        if (!isTopScreen(screen, fullArea)) {
+            return false;
         }
-        const bool bordersTop = (screen.y() == geo.y());
-        const bool bordersLeft = (screen.x() == geo.x());
-        const bool bordersBottom = (screen.y() + screen.height() == geo.y() + geo.height());
-        const bool bordersRight = (screen.x() + screen.width() == geo.x() + geo.width());
-
-        if (bordersTop && border == ElectricTop) {
-            if (!isTopScreen(screen, fullArea)) {
-                continue;
-            }
-            y = geo.y();
-            x = geo.x();
-            height = 1;
-            width = geo.width();
-            break;
+        y = screen.y();
+        x = geo.x();
+        height = 1;
+        width = geo.width();
+        break;
+    case ElectricBottom:
+        if (!isBottomScreen(screen, fullArea)) {
+            return false;
         }
-        if (bordersBottom && border == ElectricBottom) {
-            if (!isBottomScreen(screen, fullArea)) {
-                continue;
-            }
-            y = geo.y() + geo.height() - 1;
-            x = geo.x();
-            height = 1;
-            width = geo.width();
-            break;
+        y = screen.y() + screen.height() - 1;
+        x = geo.x();
+        height = 1;
+        width = geo.width();
+        break;
+    case ElectricLeft:
+        if (!isLeftScreen(screen, fullArea)) {
+            return false;
         }
-        if (bordersLeft && border == ElectricLeft) {
-            if (!isLeftScreen(screen, fullArea)) {
-                continue;
-            }
-            x = geo.x();
-            y = geo.y();
-            width = 1;
-            height = geo.height();
-            break;
-        }
-        if (bordersRight && border == ElectricRight) {
-            if (!isRightScreen(screen, fullArea)) {
-                continue;
-            }
-            x = geo.x() + geo.width() - 1;
-            y = geo.y();
-            width = 1;
-            height = geo.height();
-            break;
+        x = screen.x();
+        y = geo.y();
+        width = 1;
+        height = geo.height();
+        break;
+    case ElectricRight:
+        if (!isRightScreen(screen, fullArea)) {
+            return false;
         }
+        x = screen.x() + screen.width() - 1;
+        y = geo.y();
+        width = 1;
+        height = geo.height();
+        break;
+    default:
+        return false;
     }
 
-    if (width > 0 && height > 0) {
-        m_edges.push_back(createEdge(border, x, y, width, height, foundOutput, false));
-        Edge *edge = m_edges.back().get();
-        edge->setClient(client);
-        edge->reserve();
-        return true;
-    }
-
-    return false;
+    m_edges.push_back(createEdge(border, x, y, width, height, output, false));
+    Edge *edge = m_edges.back().get();
+    edge->setClient(client);
+    edge->reserve();
+    return true;
 }
 
 void ScreenEdges::deleteEdgeForClient(Window *window)
