@@ -359,7 +359,7 @@ static constexpr const auto s_appAltRev = kli18n("Walk Through Windows of Curren
 void TabBox::initShortcuts()
 {
     key(s_windows, &TabBox::slotWalkThroughWindows, Qt::ALT | Qt::Key_Tab);
-    key(s_windowsRev, &TabBox::slotWalkBackThroughWindows, Qt::ALT | Qt::SHIFT | Qt::Key_Backtab);
+    key(s_windowsRev, &TabBox::slotWalkBackThroughWindows, Qt::ALT | Qt::SHIFT | Qt::Key_Tab);
     key(s_app, &TabBox::slotWalkThroughCurrentAppWindows, Qt::ALT | Qt::Key_QuoteLeft);
     key(s_appRev, &TabBox::slotWalkBackThroughCurrentAppWindows, Qt::ALT | Qt::Key_AsciiTilde);
     key(s_windowsAlt, &TabBox::slotWalkThroughWindowsAlternative);
@@ -998,15 +998,16 @@ void TabBox::keyPress(int keyQt)
             return Steady;
         }
 
-        // Before testing the unshifted key (Ctrl+A vs. Ctrl+Shift+a etc.), see whether this is +Shift+Tab
-        // and check that against +Shift+Backtab (as well)
+        // Before testing the unshifted key (Ctrl+A vs. Ctrl+Shift+a etc.),
+        // see whether this is +Shift+Tab/Backtab and test that against
+        // +Shift+Backtab/Tab as well
         Qt::KeyboardModifiers mods = Qt::ShiftModifier | Qt::ControlModifier | Qt::AltModifier | Qt::MetaModifier | Qt::KeypadModifier | Qt::GroupSwitchModifier;
         mods &= keyQt;
-        if ((keyQt & ~mods) == Qt::Key_Tab) {
-            if (contains(forward, mods | Qt::Key_Backtab)) {
+        if (((keyQt & ~mods) == Qt::Key_Tab) || ((keyQt & ~mods) == Qt::Key_Backtab)) {
+            if (contains(forward, mods | Qt::Key_Backtab) || contains(forward, mods | Qt::Key_Tab)) {
                 return Forward;
             }
-            if (contains(backward, mods | Qt::Key_Backtab)) {
+            if (contains(backward, mods | Qt::Key_Backtab) || contains(backward, mods | Qt::Key_Tab)) {
                 return Backward;
             }
         }
