@@ -24,6 +24,7 @@
 #include "surface_p.h"
 #include "transaction.h"
 #include "utils/resource.h"
+#include "xx_colormanagement_v1.h"
 
 #include <wayland-server.h>
 // std
@@ -302,7 +303,7 @@ void SurfaceInterfacePrivate::surface_attach(Resource *resource, struct ::wl_res
 
 void SurfaceInterfacePrivate::surface_damage(Resource *, int32_t x, int32_t y, int32_t width, int32_t height)
 {
-    pending->damage |= QRect(x, y, width, height);
+    pending->damage += QRect(x, y, width, height);
 }
 
 void SurfaceInterfacePrivate::surface_frame(Resource *resource, uint32_t callback)
@@ -344,9 +345,9 @@ void SurfaceInterfacePrivate::surface_commit(Resource *resource)
     Transaction *transaction;
     if (sync) {
         if (!subsurface.transaction) {
-            subsurface.transaction = new Transaction();
+            subsurface.transaction = std::make_unique<Transaction>();
         }
-        transaction = subsurface.transaction;
+        transaction = subsurface.transaction.get();
     } else {
         transaction = new Transaction();
     }
@@ -354,17 +355,15 @@ void SurfaceInterfacePrivate::surface_commit(Resource *resource)
     for (SubSurfaceInterface *subsurface : std::as_const(pending->subsurface.below)) {
         auto surfacePrivate = SurfaceInterfacePrivate::get(subsurface->surface());
         if (surfacePrivate->subsurface.transaction) {
-            transaction->merge(surfacePrivate->subsurface.transaction);
-            delete surfacePrivate->subsurface.transaction;
-            surfacePrivate->subsurface.transaction = nullptr;
+            transaction->merge(surfacePrivate->subsurface.transaction.get());
+            surfacePrivate->subsurface.transaction.reset();
         }
     }
     for (SubSurfaceInterface *subsurface : std::as_const(pending->subsurface.above)) {
         auto surfacePrivate = SurfaceInterfacePrivate::get(subsurface->surface());
         if (surfacePrivate->subsurface.transaction) {
-            transaction->merge(surfacePrivate->subsurface.transaction);
-            delete surfacePrivate->subsurface.transaction;
-            surfacePrivate->subsurface.transaction = nullptr;
+            transaction->merge(surfacePrivate->subsurface.transaction.get());
+            surfacePrivate->subsurface.transaction.reset();
         }
     }
 
@@ -398,7 +397,7 @@ void SurfaceInterfacePrivate::surface_set_buffer_scale(Resource *resource, int32
 
 void SurfaceInterfacePrivate::surface_damage_buffer(Resource *resource, int32_t x, int32_t y, int32_t width, int32_t height)
 {
-    pending->bufferDamage |= QRect(x, y, width, height);
+    pending->bufferDamage += QRect(x, y, width, height);
 }
 
 void SurfaceInterfacePrivate::surface_offset(Resource *resource, int32_t x, int32_t y)
@@ -423,8 +422,6 @@ SurfaceInterface::SurfaceInterface(CompositorInterface *compositor, wl_resource
 
 SurfaceInterface::~SurfaceInterface()
 {
-    delete d->subsurface.transaction;
-    d->subsurface.transaction = nullptr;
 }
 
 SurfaceRole *SurfaceInterface::role() const
@@ -582,9 +579,7 @@ void SurfaceState::mergeInto(SurfaceState *target)
         target->colorDescription = colorDescription;
         target->colorDescriptionIsSet = true;
     }
-    if (presentationFeedback) {
-        target->presentationFeedback = std::move(presentationFeedback);
-    }
+    target->presentationFeedback = std::move(presentationFeedback);
 
     *this = SurfaceState{};
     serial = target->serial;
@@ -611,9 +606,6 @@ void SurfaceInterfacePrivate::applyState(SurfaceState *next)
     const QRectF oldBufferSourceBox = bufferSourceBox;
     const QRegion oldInputRegion = inputRegion;
 
-    if (!next->damage.isEmpty() || !next->bufferDamage.isEmpty()) {
-        current->presentationFeedback.reset();
-    }
     next->mergeInto(current.get());
     bufferRef = current->buffer;
     scaleOverride = pendingScaleOverride;
@@ -1100,6 +1092,9 @@ void SurfaceInterface::setPreferredColorDescription(const ColorDescription &desc
     if (d->frogColorManagement) {
         d->frogColorManagement->setPreferredColorDescription(descr);
     }
+    if (d->xxColorSurface) {
+        d->xxColorSurface->setPreferredColorDescription(descr);
+    }
     for (auto child : std::as_const(d->current->subsurface.below)) {
         child->surface()->setPreferredColorDescription(descr);
     }
