@@ -73,6 +73,7 @@
 #include "wayland/xdgtopleveldrag_v1.h"
 #include "wayland/xwaylandkeyboardgrab_v1.h"
 #include "wayland/xwaylandshell_v1.h"
+#include "wayland/xx_colormanagement_v1.h"
 #include "workspace.h"
 #include "x11window.h"
 #include "xdgactivationv1.h"
@@ -209,7 +210,9 @@ void WaylandServer::registerWindow(Window *window)
     if (window->readyForPainting()) {
         Q_EMIT windowAdded(window);
     } else {
-        connect(window, &Window::windowShown, this, &WaylandServer::windowAdded, Qt::SingleShotConnection);
+        connect(window, &Window::readyForPaintingChanged, this, [this, window]() {
+            Q_EMIT windowAdded(window);
+        });
     }
     m_windows << window;
 }
@@ -487,6 +490,9 @@ bool WaylandServer::init(InitializationFlags flags)
 
     new FrogColorManagementV1(m_display, m_display);
     new PresentationTime(m_display, m_display);
+    if (qEnvironmentVariableIntValue("KWIN_ENABLE_XX_COLOR_MANAGEMENT")) {
+        m_xxColorManager = new XXColorManagerV1(m_display, m_display);
+    }
     return true;
 }
 
