@@ -693,7 +693,7 @@ public:
     QRectF keepInArea(QRectF geometry, QRectF area, bool partial = false);
 
     // prefer isXXX() instead
-    virtual NET::WindowType windowType(bool direct = false) const = 0;
+    virtual NET::WindowType windowType() const = 0;
     bool hasNETSupport() const;
     bool isDesktop() const;
     bool isDock() const;
@@ -1410,6 +1410,7 @@ Q_SIGNALS:
     void paletteChanged(const QPalette &p);
     void colorSchemeChanged();
     void captionChanged();
+    void captionNormalChanged();
     void maximizedAboutToChange(MaximizeMode mode);
     void maximizedChanged();
     void transientChanged();
@@ -1433,6 +1434,7 @@ Q_SIGNALS:
     void hiddenChanged();
     void hiddenByShowDesktopChanged();
     void lockScreenOverlayChanged();
+    void readyForPaintingChanged();
 
 protected:
     Window();
